@@ -2,12 +2,10 @@ from dataclasses import field as dataclass_field
 from typing import Set
 
 from pydantic.dataclasses import dataclass
-from serde import deserialize
 
 from metaphor.bigquery.config import BigQueryRunConfig
 
 
-@deserialize
 @dataclass
 class BigQueryUsageRunConfig(BigQueryRunConfig):
     lookback_days: int = 30
