@@ -2,12 +2,10 @@ from dataclasses import field as dataclass_field
 from typing import Set
 
 from pydantic.dataclasses import dataclass
-from serde import deserialize
 
 from metaphor.redshift.config import RedshiftRunConfig
 
 
-@deserialize
 @dataclass
 class RedshiftUsageRunConfig(RedshiftRunConfig):
     lookback_days: int = 30
